/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

using System;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// This interface defines the contract that implementors of a diagram renderer should follow. A DiagramRenderer
    /// implementation will provide a method that will supply the component a IGraphics implementation that will be
    /// used to 'paint' the diagram with. The implementation will then also provide a 'disposing' method to signal
    /// when the IGraphics is no longer needed and should be disposed of (giving the implementor the chance to write
    /// out a file or to otherwise take care of external resources).
    /// </summary>
    public interface IDiagramRenderer
    {

        /// <summary>
        /// <p>This method will be called by the DependencyRenderer to retreive a IGraphics object to paint the
        /// diagram with the the diagram's expected width/height specified. The dependency is passed with this
        /// call to allow the renderer implementation to configure itself (maybe configuring a file name based
        /// on the dependency being rendered).</p>
        /// <p>
        /// The developer should note that the GetGraphics method will likely be called twice for every diagram
        /// layout.  Once to retrieve a Graphics object that will be used to measure the string sizes (to
        /// calculate the eventual size of the diagram) and a second time with the real width and height to paint
        /// to.
        /// </p>
        /// </summary>
        /// <param name="dependency">The dependency that will be rendered</param>
        /// <param name="width">The width of the diagram.</param>
        /// <param name="height">The height of the diagram.</param>
        /// <returns>A IGraphics object that can be used to paint the diagram with</returns>
        /// <exception cref="ArgumentNullException">if dependency is null</exception>
        /// <exception cref="RendererException">if an error occurs getting the graphics</exception>
        /// <exception cref="ArgumentOutOfRangeException">
        /// If width or height is less than or equal to zero.
        /// </exception>
        IGraphics GetGraphics(Dependency dependency, int width, int height);

    }

}
